;
;    Filename:  EDA Treez Example
;	 ============================



;	Processor Type
;	==============

     LIST      P=PIC18F65K22          ; list directive to define processor
     #INCLUDE <P18F65K22.INC>         ; processor specific variable definitions

;==========================================================================
;    CONFIG directives for 18F65K22
;
;   All Code and Memory Protections  are OFF, see .INC file for details if needed.




    ;CONFIG parameters set for these options
   CONFIG FOSC = INTIO1, WDTEN  = OFF, PWRTEN = OFF,  MCLRE = OFF, BOREN = OFF
    

     ; RAM Memory of 18F65K22   - Important info on SFRs

     ; Access Bank 0x00 to 0x7F.
     ; Bank 0 0x60 to 0xFF
     ; Bank 1 to 7  0x100 to 0x57FF repectively
     ; Access Bank SFRs  0xF60 to 0xFFF

     ; Bank 15 SFRs  0xF38 to 0xF5F    Must be addressed by the BSR
     ; see datasheet for all SFRs contained in this area
     ; Key registers ANSEL A to E


    cblock 0x100            ; User variables stored in bank1
	d1,d2,d3,d4				; delay work files

     endc







;	Reset vector
;	============

		ORG	0x0000


bootup	goto	Main		;go to start of main code



;	High priority interrupt vector
;	==============================

		ORG	0x0008

		retfie	FAST


;	Low priority interrupt vector
;	=============================

		ORG	0x0018
		retfie



;	Start of main program
;	=====================


; initialisation of system, clear RAM , setup i/o ports


Main	movlw	b'01100000'		; set internal osc to 8 mhz
		movwf	OSCCON


ports	clrf	PORTA           ; clear Ports
		clrf	PORTB
		clrf	PORTC
		clrf	PORTD
		clrf	PORTE

                                ; set all ports to Digital
                                ; this is complicated as the ANCON registers
                                ; are not located in the same area as most
                                ; other system registers

        movlb	0xf                 ; 65K22 CHANGE ANSEL IN BANK 15
        clrf    ANCON0          ; set all ports to Digital by clearing ANCONs
        clrf    ANCON1
        clrf    ANCON2

        movlb	0x1             ; Set BSR to 1

        movlw	b'11111111'		; set trisA as inputs
		movwf	TRISA
		movlw	b'00001111'		; set trisE as inputs
		movwf	TRISE

		movlw	b'00000000'		; set TrisB,C & D as outputs
		movwf	TRISB
		movwf	TRISC
		movwf	TRISD


flash_led
        bsf     PORTB,0         ; turn led on
        call    delay1sec       ; delay 1 seocnd at 8mhz
        bcf     PORTB,0         ; turn led off
        call    delay1sec       ; delay 1 seocnd at 8mhz
        goto    flash_led       ; loop



; Subroutines	to Main Program

delay1sec                       ; based on 8 mhz osc.
		movlw	0x11
		movwf	d1
		movlw	0x5D
		movwf	d2
		movlw	0x05
		movwf	d3
Delay_0
		decfsz	d1, f
		goto	dly1
		decfsz	d2, f
dly1	goto	dly2
		decfsz	d3, f
dly2	goto	Delay_0

		return

        END                 ; end of program code


